=== modified file 'drizzled/filesort.cc'
--- drizzled/filesort.cc	2011-08-13 18:31:31 +0000
+++ drizzled/filesort.cc	2011-08-14 12:20:36 +0000
@@ -462,8 +462,7 @@
 
 /** Read 'count' number of buffer pointers into memory. */
 
-static unsigned char *read_buffpek_from_file(internal::io_cache_st *buffpek_pointers, uint32_t count,
-                                     unsigned char *buf)
+static unsigned char *read_buffpek_from_file(internal::io_cache_st *buffpek_pointers, uint32_t count, unsigned char *buf)
 {
   uint32_t length= sizeof(buffpek)*count;
   unsigned char *tmp= buf;
@@ -473,13 +472,13 @@
     tmp= (unsigned char *)malloc(length);
   {
     if (buffpek_pointers->reinit_io_cache(internal::READ_CACHE,0L,0,0) ||
-	my_b_read(buffpek_pointers, (unsigned char*) tmp, length))
+      buffpek_pointers->read(tmp, length))
     {
-      free((char*) tmp);
-      tmp=0;
+      free(tmp);
+      tmp= 0;
     }
   }
-  return(tmp);
+  return tmp;
 }
 
 
@@ -595,7 +594,7 @@
     {
       if (indexfile)
       {
-	if (my_b_read(indexfile,(unsigned char*) ref_pos,ref_length))
+	if (indexfile->read(ref_pos, ref_length))
 	{
 	  error= errno ? errno : -1;		/* Abort */
 	  break;
@@ -732,13 +731,13 @@
 
   for (unsigned char **ptr= sort_keys + count ; sort_keys != ptr ; sort_keys++)
   {
-    if (my_b_write(tempfile, (unsigned char*) *sort_keys, (uint32_t) rec_length))
+    if (tempfile->write(*sort_keys, rec_length))
     {
       return 1;
     }
   }
 
-  if (my_b_write(buffpek_pointers, (unsigned char*) &buffpek, sizeof(buffpek)))
+  if (buffpek_pointers->write(&buffpek, sizeof(buffpek)))
   {
     return 1;
   }
@@ -1257,7 +1256,7 @@
     */
     buffpek_inst= queue.top();
     memcpy(param->unique_buff, buffpek_inst->key, rec_length);
-    if (my_b_write(to_file, (unsigned char*) buffpek_inst->key, rec_length))
+    if (to_file->write(buffpek_inst->key, rec_length))
     {
       return 1;
     }
@@ -1295,14 +1294,14 @@
       }
       if (flag == 0)
       {
-        if (my_b_write(to_file,(unsigned char*) buffpek_inst->key, rec_length))
+        if (to_file->write(buffpek_inst->key, rec_length))
         {
           return 1;
         }
       }
       else
       {
-        if (my_b_write(to_file, (unsigned char*) buffpek_inst->key+offset, res_length))
+        if (to_file->write(buffpek_inst->key+offset, res_length))
         {
           return 1;
         }
@@ -1360,8 +1359,7 @@
     max_rows-= buffpek_inst->mem_count;
     if (flag == 0)
     {
-      if (my_b_write(to_file,(unsigned char*) buffpek_inst->key,
-                     (rec_length*buffpek_inst->mem_count)))
+      if (to_file->write(buffpek_inst->key, (rec_length*buffpek_inst->mem_count)))
       {
         return 1;
       }
@@ -1374,7 +1372,7 @@
            strpos != end ;
            strpos+= rec_length)
       {
-        if (my_b_write(to_file, (unsigned char *) strpos, res_length))
+        if (to_file->write(strpos, res_length))
         {
           return 1;
         }

=== modified file 'drizzled/internal/iocache.h'
--- drizzled/internal/iocache.h	2011-08-13 18:31:31 +0000
+++ drizzled/internal/iocache.h	2011-08-14 12:20:36 +0000
@@ -27,31 +27,11 @@
 
 #define my_b_EOF INT_MIN
 
-#define my_b_read(info,Buffer,Count) \
-  ((info)->read_pos + (Count) <= (info)->read_end ?\
-   (memcpy(Buffer,(info)->read_pos,(size_t) (Count)), \
-    ((info)->read_pos+=(Count)),0) :\
-   (*(info)->read_function)((info),Buffer,Count))
-
-#define my_b_write(info,Buffer,Count) \
- ((info)->write_pos + (Count) <=(info)->write_end ?\
-  (memcpy((info)->write_pos, (Buffer), (size_t)(Count)),\
-   ((info)->write_pos+=(Count)),0) : \
-   (*(info)->write_function)((info),(Buffer),(Count)))
-
-#define my_b_get(info) \
-  ((info)->read_pos != (info)->read_end ? ((info)->read_pos++, (int) (unsigned char) (info)->read_pos[-1]) : (info)->get())
-
-#define my_b_tell(info) ((info)->tell())
-
-#define my_b_bytes_in_cache(info) (size_t) (*(info)->current_end - *(info)->current_pos)
-
-class io_cache_st;
-typedef int (*IO_CACHE_CALLBACK)(io_cache_st*);
-
 class io_cache_st    /* Used when cacheing files */
 {
 public:
+  typedef int (*IO_CACHE_CALLBACK)(io_cache_st*);
+
   /* Offset in file corresponding to the first byte of unsigned char* buffer. */
   my_off_t pos_in_file;
   /*
@@ -108,7 +88,7 @@
     certain operations might not be available and yield unpredicatable
     results. Details to be documented later
   */
-  enum cache_type type;
+  cache_type type;
   int error;
   /*
     Callbacks when the actual read I/O happens. These were added and
@@ -202,11 +182,29 @@
 
   my_off_t tell() const
   {
-    return pos_in_file + (*current_pos - request_pos);
+    return pos_in_file + *current_pos - request_pos;
+  }
+
+  int read(void* Buffer0, size_t Count)
+  {
+    unsigned char* Buffer= reinterpret_cast<unsigned char*>(Buffer0);
+    if (read_pos + Count > read_end)
+      return read_function(this, Buffer, Count);
+    memcpy(Buffer, read_pos, Count);
+    read_pos += Count;
+    return 0;
+  }
+
+  int write(const void* Buffer0, size_t Count)
+  {
+    const unsigned char* Buffer= reinterpret_cast<const unsigned char*>(Buffer0);
+    if (write_pos + Count > write_end)
+      return write_function(this, Buffer, Count);
+    memcpy(write_pos, Buffer, Count);
+    write_pos += Count;
+    return 0;
   }
 };
 
-typedef io_cache_st IO_CACHE;    /* Used when cacheing files */
-
 } /* namespace internal */
 } /* namespace drizzled */

=== modified file 'drizzled/internal/mf_iocache.cc'
--- drizzled/internal/mf_iocache.cc	2011-08-13 18:31:31 +0000
+++ drizzled/internal/mf_iocache.cc	2011-08-14 12:20:36 +0000
@@ -472,15 +472,18 @@
  */
 int io_cache_st::get()
 {
+  if (read_pos != read_end)
+    return *read_pos++;
+
   if (pre_read)
-    (*pre_read)(this);
+    pre_read(this);
 
   unsigned char buff;
-  if ((*read_function)(this, &buff, 1))
+  if (read_function(this, &buff, 1))
     return my_b_EOF;
 
   if (post_read)
-    (*post_read)(this);
+    post_read(this);
 
   return buff;
 }

=== modified file 'drizzled/records.cc'
--- drizzled/records.cc	2011-08-13 18:31:31 +0000
+++ drizzled/records.cc	2011-08-14 12:20:36 +0000
@@ -315,7 +315,7 @@
   int tmp;
   for (;;)
   {
-    if (my_b_read(info->io_cache,info->ref_pos,info->ref_length))
+    if (info->io_cache->read(info->ref_pos, info->ref_length))
       return -1;					/* End of cursor */
     if (!(tmp=info->cursor->rnd_pos(info->record,info->ref_pos)))
       break;
@@ -346,7 +346,7 @@
 */
 static int rr_unpack_from_tempfile(ReadRecord *info)
 {
-  if (my_b_read(info->io_cache, info->rec_buf, info->ref_length))
+  if (info->io_cache->read(info->rec_buf, info->ref_length))
     return -1;
   Table *table= info->table;
   (*table->sort.unpack)(table->sort.addon_field, info->rec_buf);
@@ -475,7 +475,7 @@
       length= (uint32_t) rest_of_file;
     }
 
-    if (!length || my_b_read(info->io_cache, info->getCache(), length))
+    if (!length || info->io_cache->read(info->getCache(), length))
     {
       return -1;			/* End of cursor */
     }

=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2011-08-13 15:08:14 +0000
+++ drizzled/session.cc	2011-08-14 12:20:36 +0000
@@ -1121,15 +1121,13 @@
     return false;
   }
   row_count++;
-  Item *item;
   uint32_t used_length=0,items_left=items.size();
   List<Item>::iterator li(items.begin());
 
-  if (my_b_write(cache,(unsigned char*) exchange->line_start->ptr(),
-                 exchange->line_start->length()))
+  if (cache->write(exchange->line_start->ptr(), exchange->line_start->length()))
     return true;
 
-  while ((item=li++))
+  while (Item* item=li++)
   {
     Item_result result_type=item->result_type();
     bool enclosed = (exchange->enclosed->length() &&
@@ -1137,8 +1135,7 @@
     res=item->str_result(&tmp);
     if (res && enclosed)
     {
-      if (my_b_write(cache,(unsigned char*) exchange->enclosed->ptr(),
-                     exchange->enclosed->length()))
+      if (cache->write(exchange->enclosed->ptr(), exchange->enclosed->length()))
         return true;
     }
     if (!res)
@@ -1149,10 +1146,10 @@
         {
           null_buff[0]=escape_char;
           null_buff[1]='N';
-          if (my_b_write(cache,(unsigned char*) null_buff,2))
+          if (cache->write(null_buff, 2))
             return true;
         }
-        else if (my_b_write(cache,(unsigned char*) "NULL",4))
+        else if (cache->write("NULL", 4))
           return true;
       }
       else
@@ -1242,16 +1239,15 @@
                           is_ambiguous_field_sep) ?
               field_sep_char : escape_char;
             tmp_buff[1]= *pos ? *pos : '0';
-            if (my_b_write(cache,(unsigned char*) start,(uint32_t) (pos-start)) ||
-                my_b_write(cache,(unsigned char*) tmp_buff,2))
+            if (cache->write(start, pos - start) || cache->write(tmp_buff, 2))
               return true;
             start=pos+1;
           }
         }
-        if (my_b_write(cache,(unsigned char*) start,(uint32_t) (pos-start)))
+        if (cache->write(start, pos - start))
           return true;
       }
-      else if (my_b_write(cache,(unsigned char*) res->ptr(),used_length))
+      else if (cache->write(res->ptr(), used_length))
         return true;
     }
     if (fixed_row_size)
@@ -1267,28 +1263,25 @@
         uint32_t length=item->max_length-used_length;
         for (; length > sizeof(space) ; length-=sizeof(space))
         {
-          if (my_b_write(cache,(unsigned char*) space,sizeof(space)))
+          if (cache->write(space, sizeof(space)))
             return true;
         }
-        if (my_b_write(cache,(unsigned char*) space,length))
+        if (cache->write(space, length))
           return true;
       }
     }
     if (res && enclosed)
     {
-      if (my_b_write(cache, (unsigned char*) exchange->enclosed->ptr(),
-                     exchange->enclosed->length()))
+      if (cache->write(exchange->enclosed->ptr(), exchange->enclosed->length()))
         return true;
     }
     if (--items_left)
     {
-      if (my_b_write(cache, (unsigned char*) exchange->field_term->ptr(),
-                     field_term_length))
+      if (cache->write(exchange->field_term->ptr(), field_term_length))
         return true;
     }
   }
-  if (my_b_write(cache,(unsigned char*) exchange->line_term->ptr(),
-                 exchange->line_term->length()))
+  if (cache->write(exchange->line_term->ptr(), exchange->line_term->length()))
   {
     return true;
   }
@@ -1332,10 +1325,10 @@
     res=item->str_result(&tmp);
     if (!res)					// If NULL
     {
-      if (my_b_write(cache,(unsigned char*) "",1))
+      if (cache->write("", 1))
         return 1;
     }
-    else if (my_b_write(cache,(unsigned char*) res->ptr(),res->length()))
+    else if (cache->write(res->ptr(), res->length()))
     {
       my_error(ER_ERROR_ON_WRITE, MYF(0), path.file_string().c_str(), errno);
       return 1;

=== modified file 'drizzled/sql_load.cc'
--- drizzled/sql_load.cc	2011-06-27 14:23:35 +0000
+++ drizzled/sql_load.cc	2011-08-14 12:20:36 +0000
@@ -835,7 +835,7 @@
 }
 
 
-#define GET (stack_pos != stack ? *--stack_pos : my_b_get(&cache))
+#define GET (stack_pos != stack ? *--stack_pos : cache.get())
 #define PUSH(A) *(stack_pos++)=(A)
 
 

=== modified file 'drizzled/sql_update.cc'
--- drizzled/sql_update.cc	2011-07-05 15:59:49 +0000
+++ drizzled/sql_update.cc	2011-08-14 12:20:36 +0000
@@ -385,8 +385,7 @@
 	    continue;  /* repeat the read of the same row if it still exists */
 
 	  table->cursor->position(table->getInsertRecord());
-	  if (my_b_write(&tempfile,table->cursor->ref,
-			 table->cursor->ref_length))
+	  if (tempfile.write(table->cursor->ref, table->cursor->ref_length))
 	  {
 	    error=1;
 	    break;

=== modified file 'plugin/myisam/mi_check.cc'
--- plugin/myisam/mi_check.cc	2011-08-13 18:31:31 +0000
+++ plugin/myisam/mi_check.cc	2011-08-14 12:20:36 +0000
@@ -911,9 +911,8 @@
       goto err2;
     switch (info->s->data_file_type) {
     case STATIC_RECORD:
-      if (my_b_read(&param->read_cache,(unsigned char*) record,
-		    info->s->base.pack_reclength))
-	goto err;
+      if (param->read_cache.read(record, info->s->base.pack_reclength))
+        goto err;
       start_recpos=pos;
       pos+=info->s->base.pack_reclength;
       splits++;
@@ -2398,8 +2397,7 @@
   case STATIC_RECORD:
     for (;;)
     {
-      if (my_b_read(&sort_param->read_cache,sort_param->record,
-		    share->base.pack_reclength))
+      if (sort_param->read_cache.read(sort_param->record, share->base.pack_reclength))
       {
 	if (sort_param->read_cache.error)
 	  param->out_flag |= O_DATA_LOST;
@@ -2757,8 +2755,7 @@
   {
     switch (sort_info->new_data_file_type) {
     case STATIC_RECORD:
-      if (my_b_write(&info->rec_cache,sort_param->record,
-		     share->base.pack_reclength))
+      if (info->rec_cache.write(sort_param->record, share->base.pack_reclength))
       {
 	mi_check_print_error(param,"%d when writing to datafile",errno);
 	return(1);
@@ -3140,7 +3137,7 @@
   {
     unsigned char buff[MEMMAP_EXTRA_MARGIN];
     memset(buff, 0, sizeof(buff));
-    if (my_b_write(&info->rec_cache,buff,sizeof(buff)))
+    if (info->rec_cache.write(buff, sizeof(buff)))
     {
       mi_check_print_error(sort_info->param,
 			   "%d when writing to datafile",errno);

=== modified file 'plugin/myisam/mi_dynrec.cc'
--- plugin/myisam/mi_dynrec.cc	2011-08-13 17:10:16 +0000
+++ plugin/myisam/mi_dynrec.cc	2011-08-14 12:20:36 +0000
@@ -721,8 +721,7 @@
 			 length+extra_length+del_length,filepos))
       goto err;
     }
-    else if (my_b_write(&info->rec_cache,(unsigned char*) *record-head_length,
-			length+extra_length+del_length))
+    else if (info->rec_cache.write(*record-head_length, length+extra_length+del_length))
       goto err;
   }
   else

=== modified file 'plugin/myisam/mi_statrec.cc'
--- plugin/myisam/mi_statrec.cc	2011-08-13 18:31:31 +0000
+++ plugin/myisam/mi_statrec.cc	2011-08-14 12:20:36 +0000
@@ -49,14 +49,13 @@
     }
     if (info->opt_flag & WRITE_CACHE_USED)
     {				/* Cash in use */
-      if (my_b_write(&info->rec_cache, record,
-		     info->s->base.reclength))
+      if (info->rec_cache.write(record, info->s->base.reclength))
 	goto err;
       if (info->s->base.pack_reclength != info->s->base.reclength)
       {
 	uint32_t length=info->s->base.pack_reclength - info->s->base.reclength;
 	memset(temp, 0, length);
-	if (my_b_write(&info->rec_cache, temp,length))
+	if (info->rec_cache.write(temp,length))
 	  goto err;
       }
     }
@@ -252,12 +251,11 @@
   }
 
 	/* Read record with cacheing */
-  error=my_b_read(&info->rec_cache,(unsigned char*) buf,share->base.reclength);
+  error= info->rec_cache.read(buf, share->base.reclength);
   if (info->s->base.pack_reclength != info->s->base.reclength && !error)
   {
     char tmp[8];				/* Skill fill bytes */
-    error=my_b_read(&info->rec_cache,(unsigned char*) tmp,
-		    info->s->base.pack_reclength - info->s->base.reclength);
+    error= info->rec_cache.read(tmp, info->s->base.pack_reclength - info->s->base.reclength);
   }
   if (locked)
     _mi_writeinfo(info,0);		/* Unlock keyfile */

=== modified file 'plugin/myisam/sort.cc'
--- plugin/myisam/sort.cc	2011-08-13 18:31:31 +0000
+++ plugin/myisam/sort.cc	2011-08-14 12:20:36 +0000
@@ -214,13 +214,11 @@
       goto err;
     }
 
-    while (!my_b_read(&tempfile_for_exceptions,(unsigned char*)&key_length,
-		      sizeof(key_length))
-        && !my_b_read(&tempfile_for_exceptions,(unsigned char*)sort_keys,
-		      (uint) key_length))
+    while (not tempfile_for_exceptions.read(&key_length, sizeof(key_length))
+        && not tempfile_for_exceptions.read(sort_keys, key_length))
     {
-	if (_mi_ck_write(idx,keyno,(unsigned char*) sort_keys,key_length-ref_length))
-	  goto err;
+      if (_mi_ck_write(idx,keyno,(unsigned char*) sort_keys,key_length-ref_length))
+        goto err;
     }
   }
 
@@ -412,17 +410,12 @@
         continue;
       }
 
-      while (!got_error &&
-	     !my_b_read(&sinfo->tempfile_for_exceptions,(unsigned char*)&key_length,
-			sizeof(key_length)))
+      while (!got_error && not sinfo->tempfile_for_exceptions.read(&key_length, sizeof(key_length)))
       {
         unsigned char ft_buf[10];
-        if (key_length > sizeof(ft_buf) ||
-            my_b_read(&sinfo->tempfile_for_exceptions, (unsigned char*)ft_buf,
-                      (uint)key_length) ||
-            _mi_ck_write(info, sinfo->key, (unsigned char*)ft_buf,
-                         key_length - info->s->rec_reflength))
-          got_error=1;
+        if (key_length > sizeof(ft_buf) || sinfo->tempfile_for_exceptions.read(ft_buf, (uint)key_length) 
+          || _mi_ck_write(info, sinfo->key, (unsigned char*)ft_buf, key_length - info->s->rec_reflength))
+          got_error= 1;
       }
     }
   }
@@ -447,7 +440,7 @@
 
   for (end=sort_keys+count ; sort_keys != end ; sort_keys++)
   {
-    if (my_b_write(tempfile,(unsigned char*) *sort_keys,(uint) sort_length))
+    if (tempfile->write(*sort_keys, sort_length))
       return(1);
   }
   return(0);
@@ -461,9 +454,9 @@
   uint16_t len = _mi_keylength(info->keyinfo, (unsigned char*) bufs);
 
   /* The following is safe as this is a local file */
-  if ((err= my_b_write(to_file, (unsigned char*)&len, sizeof(len))))
+  if ((err= to_file->write(&len, sizeof(len))))
     return (err);
-  if ((err= my_b_write(to_file,bufs, (uint) len)))
+  if ((err= to_file->write(bufs, len)))
     return (err);
   return (0);
 }
@@ -500,8 +493,8 @@
   if (not tempfile->inited() && tempfile->open_cached_file(P_tmpdir, "ST", DISK_BUFFER_SIZE, info->sort_info->param->myf_rw))
     return(1);
 
-  if (my_b_write(tempfile,(unsigned char*)&key_length,sizeof(key_length)) ||
-      my_b_write(tempfile,(unsigned char*)key,(uint) key_length))
+  if (tempfile->write(&key_length, sizeof(key_length)) ||
+      tempfile->write(key, key_length))
     return(1);
   return(0);
 } /* write_key */
@@ -649,12 +642,11 @@
 }
 
 
-static int  write_merge_key(MI_SORT_PARAM *info,
+static int  write_merge_key(MI_SORT_PARAM*,
 				  internal::io_cache_st *to_file, unsigned char *key,
 				  uint32_t sort_length, uint32_t count)
 {
-  (void)info;
-  return my_b_write(to_file, key, (size_t) sort_length*count);
+  return to_file->write(key, sort_length*count);
 }
 
 /*

